@@ -1,7 +1,7 @@
 # Generate raw data, with numeric, binary, and categorical variables
-\donttest{
-# Run where Python available
-if (reticulate::py_module_available("numpy")) {
+\dontrun{
+# Run where Python available and configured correctly
+if (python_configured()) {
 set.seed(89)
 n_obs <- 10000
 raw_data <- data.table(a = sample(c("red","yellow","blue",NA),n_obs, replace = TRUE),
