@@ -31,8 +31,13 @@ import pandas as pd
 import tensorflow as tf
 import os
 
+os.environ['TF_CPP_MIN_LOG_LEVEL'] = '3'
+
 if tf.__version__[0] == '2':
   import tensorflow_addons as tfa
+  tf.compat.v1.logging.set_verbosity(tf.compat.v1.logging.ERROR)
+else:
+  tf.logging.set_verbosity(tf.logging.ERROR)
 
 from sklearn.metrics import mean_squared_error as mse
 import random
